# -*- coding: utf-8 -*-
from django.db import models
from django.utils.encoding import force_text, python_2_unicode_compatible
from django.utils.html import strip_tags
from django.utils.text import Truncator
from django.utils.translation import ugettext_lazy as _

from cms.models.pluginmodel import CMSPlugin


@python_2_unicode_compatible
class Diptych(CMSPlugin):
    """
    A simple diptych block where you can choose alignment for content and image
    """
    ALIGNMENT_CHOICES = [
        ('left', _('Content to the left, image to the right')),
        ('right', _('Image to the left, content to the reft')),
    ]

    alignment = models.CharField(
        _('Alignment'),
        choices=ALIGNMENT_CHOICES,
        max_length=15,
        blank=False,
        default='left',
    )
    background = models.ImageField(
        _('Background image'),
        upload_to='blocks/diptych/%y/%m',
        max_length=255,
        null=True,
        blank=False,
        default=None,
    )
    content = models.TextField(
        _(u"Content"),
        blank=False,
        default="",
    )

    def __init__(self, *args, **kwargs):
        super(Diptych, self).__init__(*args, **kwargs)
        self.content = force_text(self.content)

    def __str__(self):
        return Truncator(strip_tags(self.content)).words(4, truncate="...")

    def save(self, *args, **kwargs):
        super(Diptych, self).save(*args, **kwargs)

    class Meta:
        verbose_name = _('Diptych')
        verbose_name_plural = _('Diptychs')
